@@ -15,6 +15,8 @@
 
 #include "bonobo-ui-toolbar-item.h"
 
+#ifndef BONOBO_UI_DISABLE_DEPRECATED
+
 G_BEGIN_DECLS
 
 #define BONOBO_TYPE_UI_TOOLBAR_BUTTON_ITEM		(bonobo_ui_toolbar_button_item_get_type ())
@@ -36,13 +38,15 @@ typedef struct {
 
 	/* Virtual methods */
 	void (* set_icon)       (BonoboUIToolbarButtonItem *button_item,
-				 GtkWidget                 *image);
+				 gpointer                   image);
 	void (* set_label)      (BonoboUIToolbarButtonItem *button_item,
 				 const char                *label);
 
 	/* Signals.  */
 	void (* clicked)	(BonoboUIToolbarButtonItem *toolbar_button_item);
 	void (* set_want_label) (BonoboUIToolbarButtonItem *toolbar_button_item);
+
+	gpointer dummy[2];
 } BonoboUIToolbarButtonItemClass;
 
 GtkType    bonobo_ui_toolbar_button_item_get_type           (void) G_GNUC_CONST;
@@ -54,7 +58,7 @@ GtkWidget *bonobo_ui_toolbar_button_item_new                (GdkPixbuf
 							     const char                *label);
 
 void       bonobo_ui_toolbar_button_item_set_image          (BonoboUIToolbarButtonItem *button_item,
-							     GtkWidget                 *image);
+							     gpointer                   image);
 void       bonobo_ui_toolbar_button_item_set_label          (BonoboUIToolbarButtonItem *button_item,
 							     const char                *label);
 
@@ -62,4 +66,6 @@ GtkButton *bonobo_ui_toolbar_button_item_get_button_widget  (BonoboUIToolbarButt
 
 G_END_DECLS
 
+#endif
+
 #endif /* _BONOBO_UI_TOOLBAR_BUTTON_ITEM_H_ */
